@@ -7,17 +7,15 @@ BEGIN {
     use Handel::ConfigReader;
     use Handel::Exception;
     use Handel::L10N qw(translate);
-
 };
 
 my $cfg = Handel::ConfigReader->new();
-my $db_driver = $cfg->{'db_driver'};
-my $db_host   = $cfg->{'db_host'};
-my $db_port   = $cfg->{'db_port'};
-my $db_name   = $cfg->{'db_name'};
-my $db_user   = $cfg->{'db_user'};
-my $db_pass   = $cfg->{'db_pass'};
-
+my $db_driver  = $cfg->{'db_driver'};
+my $db_host    = $cfg->{'db_host'};
+my $db_port    = $cfg->{'db_port'};
+my $db_name    = $cfg->{'db_name'};
+my $db_user    = $cfg->{'db_user'};
+my $db_pass    = $cfg->{'db_pass'};
 my $datasource = "dbi:$db_driver:dbname=$db_name";
 
 if ($db_host) {
@@ -56,6 +54,14 @@ sub _croak {
     return;
 };
 
+sub accessor_name {
+    my ($class, $column) = @_;
+
+    $column =~ s/^(price)$/_$1/;
+
+    return $column;
+}
+
 sub has_wildcard {
     my $filter = shift;
 
@@ -118,7 +124,7 @@ Handel::DBI - Base DBI class used by cart/order objects
 
 =head1 VERSION
 
-    $Id: DBI.pm 274 2005-03-02 02:22:05Z claco $
+    $Id: DBI.pm 284 2005-03-04 02:28:52Z claco $
 
 =head1 DESCRIPTION
 
